@@ -8,7 +8,6 @@ namespace dtwclust {
 KahanSummer::KahanSummer(double * const x, const int nrows, const int ncols)
     : x_(x)
     , nrows_(nrows)
-    , ncols_(ncols)
     , c_(std::vector<double>(nrows * ncols))
     , y_(std::vector<double>(nrows * ncols))
     , t_(std::vector<double>(nrows * ncols))
@@ -19,10 +18,11 @@ void KahanSummer::reset() {
 }
 
 void KahanSummer::add(const double value, const int i, const int j) {
-    y_[d2s(i,j,nrows_)] = value - c_[d2s(i,j,nrows_)];
-    t_[d2s(i,j,nrows_)] = x_[d2s(i,j,nrows_)] + y_[d2s(i,j,nrows_)];
-    c_[d2s(i,j,nrows_)] = (t_[d2s(i,j,nrows_)] - x_[d2s(i,j,nrows_)]) - y_[d2s(i,j,nrows_)];
-    x_[d2s(i,j,nrows_)] = t_[d2s(i,j,nrows_)];
+    int id = i + j * nrows_;
+    y_[id] = value - c_[id];
+    t_[id] = x_[id] + y_[id];
+    c_[id] = (t_[id] - x_[id]) - y_[id];
+    x_[id] = t_[id];
 }
 
 } // namespace dtwclust
